==========
Governance
==========

Neo is a community-developed project,
we welcome contributions from anyone who is interested in the project.
The project maintainers are the members of the `Neo maintainers team`_.
All contributors agree to abide by the Code of Conduct, see the file `CODE_OF_CONDUCT.md`_.

Contributions
=============

All contributions must be by pull request,
with the exception of quick bug fixes affecting fewer than ten lines of code.
Normally, pull requests may be approved and merged by any maintainer,
although anyone is welcome to join in the discussion.
In case of disagreement with a decision, we will try to reach a consensus between maintainers,
taking account of any input from the wider community.
If consensus cannot be reached, decisions will be based on a majority vote among the maintainers,
with the caveats that (i) only one vote per institution is allowed (i.e. in the case where several
maintainers belong to the same institution they will have to agree among themselves how to vote)
and (ii) a quorum of three maintainers must be achieved.

.. _section-maintainers:

Maintainers
===========

Any contributor who has had at least three pull requests accepted may be nominated as a maintainer.
Nominations must be approved by at least two existing maintainers, with no dissenting maintainer.
In case of disagreement, decisions on accepting new maintainers will be based on a majority vote
as above. Decisions on removing maintainers from the list are based on majority vote.

The current maintainers are:

- Andrew Davison (`@apdavison`_)
- Samuel Garcia (`@samuelgarcia`_)
- Julia Sprenger (`@JuliaSprenger`_)
- Michael Denker (`@mdenker`_)
- Alessio Buccino (`@alejoe91`_)


.. _`Neo maintainers team`: https://github.com/orgs/NeuralEnsemble/teams/neo-maintainers
.. _`CODE_OF_CONDUCT.md`: https://github.com/NeuralEnsemble/python-neo/blob/master/CODE_OF_CONDUCT.md
.. _`@apdavison`: https://github.com/apdavison
.. _`@samuelgarcia`: https://github.com/samuelgarcia
.. _`@JuliaSprenger`: https://github.com/JuliaSprenger
.. _`@mdenker`: https://github.com/mdenker
.. _`@alejoe91`: https://github.com/alejoe91
